=== modified file 'bzrlib/delta.py'
--- bzrlib/delta.py	2007-02-05 15:27:54 +0000
+++ bzrlib/delta.py	2007-02-05 15:34:47 +0000
@@ -255,7 +255,8 @@
 class ChangeReporter(object):
     """Report changes between two trees"""
 
-    def __init__(self, old_inventory, output=None, suppress_root_add=True):
+    def __init__(self, old_inventory, output=None, suppress_root_add=True,
+                 output_file=None):
         """Constructor
 
         :param old_inventory: The inventory of the old tree
@@ -263,8 +264,15 @@
             accepts a format and parameters.
         :param supress_root_add: If true, adding the root will be ignored
             (i.e. when a tree has just been initted)
+        :param output_file: If supplied, a file-like object to write to.
+            Only one of output and output_file may be supplied.
         """
         self.old_inventory = old_inventory
+        if output_file is not None:
+            if output is not None:
+                raise BzrError('Cannot specify both output and output_file')
+            def output(fmt, *args):
+                output_file.write((fmt % args) + '\n')
         self.output = output
         if self.output is None:
             from bzrlib import trace

=== modified file 'bzrlib/status.py'
--- bzrlib/status.py	2007-02-05 15:27:54 +0000
+++ bzrlib/status.py	2007-02-05 15:34:47 +0000
@@ -144,9 +144,8 @@
                 (old, new), require_versioned=False)
             changes = new._iter_changes(old, show_unchanged,
                                         specific_file_ids)
-            def output(fmt, *args):
-                to_file.write((fmt % args) + '\n')
-            reporter = _mod_delta.ChangeReporter(old.inventory, output)
+            reporter = _mod_delta.ChangeReporter(old.inventory,
+                output_file=to_file)
             _mod_delta.report_changes(changes, reporter)
         else:
             delta = new.changes_from(old, want_unchanged=show_unchanged,

